Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2015-12-01 10:52:24 +0300
committerCampbell Barton <ideasman42@gmail.com>2015-12-01 10:53:26 +0300
commit9e56c570c3fbca4bae9a1da24828b6e640299f99 (patch)
tree5698d3d2dc2f8ae2dc77c070d9beefa4e69e109e /source/blender/editors/transform/transform_orientations.c
parent2f80d304b0d50ea25367219b339bcfaa7958bbf4 (diff)
Cleanup: use more logical names for View3D.around
D1651 (own patch)
Diffstat (limited to 'source/blender/editors/transform/transform_orientations.c')
-rw-r--r--source/blender/editors/transform/transform_orientations.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/blender/editors/transform/transform_orientations.c b/source/blender/editors/transform/transform_orientations.c
index a1bb6f4e0f3..2ea18d509f0 100644
--- a/source/blender/editors/transform/transform_orientations.c
+++ b/source/blender/editors/transform/transform_orientations.c
@@ -591,7 +591,7 @@ int getTransformOrientation_ex(const bContext *C, float normal[3], float plane[3
Base *base;
Object *ob = OBACT;
int result = ORIENTATION_NONE;
- const bool activeOnly = (around == V3D_ACTIVE);
+ const bool activeOnly = (around == V3D_AROUND_ACTIVE);
zero_v3(normal);
zero_v3(plane);
@@ -854,7 +854,7 @@ int getTransformOrientation_ex(const bContext *C, float normal[3], float plane[3
/* exception */
if (flag) {
float tvec[3];
- if ((around == V3D_LOCAL) ||
+ if ((around == V3D_AROUND_LOCAL_ORIGINS) ||
ELEM(flag, SEL_F2, SEL_F1 | SEL_F3, SEL_F1 | SEL_F2 | SEL_F3))
{
BKE_nurb_bezt_calc_normal(nu, bezt, tvec);
@@ -1044,8 +1044,8 @@ int getTransformOrientation_ex(const bContext *C, float normal[3], float plane[3
int getTransformOrientation(const bContext *C, float normal[3], float plane[3])
{
- /* dummy value, not V3D_ACTIVE and not V3D_LOCAL */
- short around = V3D_CENTER;
+ /* dummy value, not V3D_AROUND_ACTIVE and not V3D_AROUND_LOCAL_ORIGINS */
+ short around = V3D_AROUND_CENTER_BOUNDS;
return getTransformOrientation_ex(C, normal, plane, around);
}